@@ -42,7 +42,9 @@ if( isset($params['submit']) )
   {
     $this->SetPreference('croptofit_default_loc',trim($params['croptofit_default_loc']));
     $this->SetPreference('cache_age',(int)$params['cache_age']);
+    $this->SetPreference('cache_path',$params['cache_path']);
     $this->SetPreference('image_url_prefix',trim($params['image_url_prefix']));
+    $this->SetPreference('silent',(int)$params['silent']);
     $this->SetPreference('image_url_hascachedir',(isset($params['image_url_hascachedir']))?(int)$params['image_url_hascachedir']:0);
     $this->SetMessage($this->Lang('msg_prefsupdated'));
   }
@@ -65,7 +67,9 @@ else if( isset($params['clear_all']) )
   {
     // just nuke the cache directory completely.
     $config = cmsms()->GetConfig();
-    $dir = $config['uploads_path'].'/_'.$this->GetName();
+    //$dir = $config['uploads_path'].'/_'.$this->GetName();
+	$cache_path = $this->GetPreference('cache_path', cms_join_path('uploads', '_'.$this->GetName()));
+	$dir = cms_join_path($config['root_path'], $cache_path);	
     cge_dir::recursive_rmdir($dir);
     $this->SetMessage($this->Lang('msg_cacheremoved'));
   }
