@@ -99,16 +99,17 @@ $lang['param_filter_resize'] = 'type,number[,number[,upscale]] - Perform a resiz
   <li>c,x,y - Perform a resize to a custom size (without retaining aspect ratio).  i.e: filter_resize=c,50,75 to create a thumbnail that is 50x75 pixels.</li>.
   <li>c,x,y,0 - Perform a resize to a custom size (without retaining aspect ratio).  i.e: filter_resize=c,50,75 to create a thumbnail that is 50x75 pixels. Do not allow upscaling.</li>.
 </ul>';
-$lang['param_filter_resizetofit'] = '(width,height[,color[,alpha]]) - Perform a resize on the image specified. This attempts to rescale the image to the destination size while reatining aspect ratio, the image is centered in the box specified (either horizontally or vertically depending upon aspect ratio and the destination size, and the image is surrounded by the supplied color.  Colors can be specified by name (see the X11 color names), or by #nnnnnn hexadecimal format, or as rgb values separated by a : i.e:  filter_croptofit=600,400,#ff0000.  The special color value &quot;transparent&quot; can be specified to force the background to be transparent.   An alpha value may be specified between 0 and 127 to specify different degrees of translucency for the background.   At no time will this plugin perform any upscaling.';
+$lang['param_filter_resizetofit'] = '(width,height[,color[,alpha]]) - Perform a resize on the image specified. This attempts to rescale the image to the destination size while reatining aspect ratio, the image is centered in the box specified (either horizontally or vertically depending upon aspect ratio and the destination size, and the image is surrounded by the supplied color.  Colors can be specified by name (see the X11 color names), or by #nnnnnn hexadecimal format, or as rgb values separated by a : i.e:  filter_croptofit=600,400,#ff0000.  The special color value &quot;transparent&quot; can be specified to force the background to be transparent (for image types that support it).   An alpha value may be specified between 0 and 127 to specify different degrees of translucency for the background.   At no time will this plugin perform any upscaling.';
 $lang['param_filter_rotate'] = '(angle) Specify the integer angle (counter clockwise) to rotate the image, The image is rotated about its center.';
 $lang['param_filter_roundedcorners'] = '(radius) Specify an integer radius (in pixels) for rounding the corners.';
+$lang['param_filter_sharpen'] = '(integer) Specify an adjustment (between -10 and 10) to the sharpen filter.  Lower values will lighten the sharpening effect.  Higher values increase it.  Note: sharpening may have adverse effects on some images, and should usually be specified as the last filter, unless the filter may add borders tothe image.';
 $lang['param_filter_watermark'] = '(anything), Specify that the watermark (as specified in the CGExtensions admin panel) should be applied to the image';
 $lang['param_height'] = 'Used when creating an img tag, specify the value for the height attribute.  Note, if this is not specified a value will be automatically calculated for this attribute so that most generated img tags will validate.  You can override this auto calculation with the &quot;noauto&quot; parameter.  This parameter will also be used in conjunction with the &quot;width&quot; parameter to perform a final resizing or croptofit filter (unless the &quot;noautoscale&quot; parameter is also supplied)';
 $lang['param_id'] = 'Used when creating an img tag, allows specifying an id attribute to include on the tag.  i.e: id="sometag"';
 $lang['param_max_height'] = 'This parameter allows specifying a maximum height for the converted images.';
 $lang['param_max_width'] = 'This parameter allows specifying a maximum width for the converted images.';
 $lang['param_name'] = 'Used when creating an img tag, specify the value for the name attribute.';
-$lang['param_noauto'] = 'Do not automatically calcualte parameters for the img tag.  This may cause your site to fail validation if some required parameters (width,height,alt) are not specified';
+$lang['param_noauto'] = 'Do not automatically calculate parameters for the img tag.  This may cause your site to fail validation if some required parameters (width,height,alt) are not specified.  Additionally, if the width and height attributes are specified, this parameter will ensure that they will not be overridden by the actual size of the processed image.';
 $lang['param_noautoscale'] = 'If width and height parameters are specified, this parameter will disable automatic scaling of the image.  This parameter will be disabled for mobile browsers';
 $lang['param_nobcache'] = 'Do not allow the resized image to cache in the browser (useful for development purposes) this adds a unique number as a parameter to the image which will force the browser not to cache the image.';
 $lang['param_nobreakpoints'] = '<strong>Experimental:</strong> For responsive image handling, disable breakpoints and force regular resize handling for images on mobile browsers.';
@@ -124,7 +125,7 @@ $lang['param_rel'] = 'Used when building an image tag allows specifying an optio
 $lang['param_silent'] = 'Silently ignore errors';
 $lang['param_src'] = 'Specify the source for the image processing (if any) or the generated img tag.  Note, this parameter is flexible, and the module will attempt many methods to find the source image file on the web server as follows:
 <ul>
-  <li>First look to see if the specified src value exists as a file on the filesystem.</li>
+  <li>First look to see if the specified src value exists as a file on the filesystem <strong>Below the CMSMS root URL</strong></li>
   <li>Next, check if the value specified for the src parameter is a URL and begins with the uploads_url (as specified in the config.php)</li>
   <li>Next, check if the value specified for the src parameter is a URL and begins with the root_url (as specified in the config.php)</li>
   <li>Next, check if the value specified for the src parameter is a URL and begins with the ssl_url (as specified in the config.php)</li>
