@@ -42,56 +42,38 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
   private $_loc = 'c';
   private $_upscale = 0;
   static private $_valid_locs = array('tl','tc','tr','cl','c','cr','bl','bc','br');
-
-    
+   
   public function __construct($input)
   {
     $mod = cms_utils::get_module('CGSmartImage');
     $this->_loc = $mod->GetPreference('croptofit_default_loc','c');
-    if( cge_array::is_hash($input) )
-      {
-	if( isset($input['width']) )
-	  {
-	    $this->_dest_w = (int)$input['width'];
-	    $this->_dest_h = (int)$input['height'];
-	  }
-	else if ( isset($input['w']) )
-	  {
-	    $this->_dest_w = (int)$input['w'];
-	    $this->_dest_h = (int)$input['h'];
-	  }
-	if( isset($input['loc']) && in_array($input['loc'],self::$_valid_locs) )
-	  {
-	    $this->_loc = $input['loc'];
-	  }
-	if( isset($input['upscale']) ) {
-	  $this->_upscale = (int)$input['upscale'];
-	}
+    if( cge_array::is_hash($input) ) {
+      if( isset($input['width']) ) {
+	$this->_dest_w = (int)$input['width'];
+	$this->_dest_h = (int)$input['height'];
       }
-    else if( is_array($input)  )
-      {
-	if( count($input) >= 2 )
-	  {
-	    $this->_dest_w = (int)trim($input[0]);
-	    $this->_dest_h = (int)trim($input[1]);
-	    if( count($input) >= 3 && in_array($input[2],self::$_valid_locs) ) {
-	      $this->_loc = $input[2];
-	    }
-	    if( count($input) >= 4 ) {
-	      $this->_upscale = (int)$input[3];
-	    }
-	  }
+      else if ( isset($input['w']) ) {
+	$this->_dest_w = (int)$input['w'];
+	$this->_dest_h = (int)$input['h'];
       }
+      if( isset($input['loc']) && in_array($input['loc'],self::$_valid_locs) ) $this->_loc = $input['loc'];
+      if( isset($input['upscale']) ) $this->_upscale = (int)$input['upscale'];
+    }
+    else if( is_array($input)  ) {
+      if( count($input) >= 2 ) {
+	$this->_dest_w = (int)trim($input[0]);
+	$this->_dest_h = (int)trim($input[1]);
+	if( count($input) >= 3 && in_array($input[2],self::$_valid_locs) ) $this->_loc = $input[2];
+	if( count($input) >= 4 ) $this->_upscale = (int)$input[3];
+      }
+    }
 
     if( !$this->_upscale ) {
       $this->_dest_w = cgsi_utils::trim_to_device('width',$this->_dest_w);
       $this->_dest_h = cgsi_utils::trim_to_device('height',$this->_dest_h);
     }
 
-    if( $this->_dest_h <= 0 || $this->_dest_w <= 0 )
-      {
-	throw new Exception('Invalid values specified for Croptofit filter constructor');
-      }
+    if( $this->_dest_h <= 0 || $this->_dest_w <= 0 ) throw new Exception('Invalid values specified for Croptofit filter constructor');
   }
 
 
@@ -104,11 +86,7 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
     }
 
     // quick optimization (nothing to do)
-    if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] )
-      {
-	//$src['width'] = $src['width'];
-	return $src;
-      }
+    if( $this->_dest_w == $src['width'] && $this->_dest_h == $src['height'] ) return $src;
 
     //
     // note:  this code developed by using the following page as a reference
@@ -121,28 +99,25 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
     // the desired area by at least one dimension.
     $new_h = '';
     $new_w = '';
-    if( $src_ratio >= $dest_ratio )
-      {
-	$new_h = (int) $this->_dest_h;
-	$new_w = (int) ceil($this->_dest_h * $src_ratio);
-      }
-    else if( $src_ratio < $dest_ratio )
-      {
-	$new_w = (int) $this->_dest_w;
-	$new_h = (int) ceil($this->_dest_w / $src_ratio );
-      }
+    if( $src_ratio >= $dest_ratio ) {
+      $new_h = (int) $this->_dest_h;
+      $new_w = (int) ceil($this->_dest_h * $src_ratio);
+    }
+    else if( $src_ratio < $dest_ratio ) {
+      $new_w = (int) $this->_dest_w;
+      $new_h = (int) ceil($this->_dest_w / $src_ratio );
+    }
 
     // get the transparent color of the source image.
     $tc = imagecolorat($src['rsrc'],0,$src['height']-1);
     $tr = $tg = $tb = 0; $ta = 127;
-    if( $tc > 0 )
-      {
-	$tmp = imagecolorsforindex($src['rsrc'],$tc);
-	$tr = $tmp['red'];
-	$tg = $tmp['green'];
-	$tb = $tmp['blue'];
-	$ta = $tmp['alpha'];
-      }
+    if( $tc > 0 ) {
+      $tmp = imagecolorsforindex($src['rsrc'],$tc);
+      $tr = $tmp['red'];
+      $tg = $tmp['green'];
+      $tb = $tmp['blue'];
+      $ta = $tmp['alpha'];
+    }
 
     // create temporary transparent image
     $tmp_rsrc = imagecreatetruecolor($new_w,$new_h);
@@ -153,61 +128,57 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
 
     // resize the big image into the temporary transparent image
     $res = imagecopyresampled($tmp_rsrc,$src['rsrc'],0,0,0,0,$new_w,$new_h,$src['width'],$src['height']);
-    if( $res === FALSE )
-      {
-	throw new Exception('Croptofit - stage 1 - failed');
-      }
+    if( $res === FALSE ) throw new Exception('Croptofit - stage 1 - failed');
 
     // calculate the offset into the destination iamge.
-    switch( $this->_loc )
-      {
-      case 'tl':
-	$x0 = 0;
-	$y0 = 0;
-	break;
+    switch( $this->_loc ) {
+    case 'tl':
+      $x0 = 0;
+      $y0 = 0;
+      break;
 
-      case 'tc':
-	$x0 = (int)( $new_w - $this->_dest_w ) / 2;
-	$y0 = 0;
-	break;
+    case 'tc':
+      $x0 = (int)( $new_w - $this->_dest_w ) / 2;
+      $y0 = 0;
+      break;
 
-      case 'tr':
-	$x0 = (int)( $new_w - $this->_dest_w );
-	$y0 = 0;
-	break;
+    case 'tr':
+      $x0 = (int)( $new_w - $this->_dest_w );
+      $y0 = 0;
+      break;
 
-      case 'cl':
-	$x0 = 0;
-	$y0 = (int)( $new_h - $this->_dest_h ) / 2;
-	break;
+    case 'cl':
+      $x0 = 0;
+      $y0 = (int)( $new_h - $this->_dest_h ) / 2;
+      break;
 
-      case 'cr':
-	$x0 = (int)( $new_w - $this->_dest_w );
-	$y0 = (int)( $new_h - $this->_dest_h ) / 2;
-	break;
+    case 'cr':
+      $x0 = (int)( $new_w - $this->_dest_w );
+      $y0 = (int)( $new_h - $this->_dest_h ) / 2;
+      break;
 
-      case 'bl':
-	$x0 = 0;
-	$y0 = (int)( $new_h - $this->_dest_h );
-	break;
+    case 'bl':
+      $x0 = 0;
+      $y0 = (int)( $new_h - $this->_dest_h );
+      break;
 
-      case 'bc':
-	$x0 = (int)( $new_w - $this->_dest_w ) / 2;
-	$y0 = (int)( $new_h - $this->_dest_h );
-	break;
+    case 'bc':
+      $x0 = (int)( $new_w - $this->_dest_w ) / 2;
+      $y0 = (int)( $new_h - $this->_dest_h );
+      break;
 
-      case 'br':
-	$x0 = (int)( $new_w - $this->_dest_w );
-	$y0 = (int)( $new_h - $this->_dest_h );
-	break;
+    case 'br':
+      $x0 = (int)( $new_w - $this->_dest_w );
+      $y0 = (int)( $new_h - $this->_dest_h );
+      break;
 
-      case 'c':
-      default:
-	// center
-	$x0 = (int)( $new_w - $this->_dest_w ) / 2;
-	$y0 = (int)( $new_h - $this->_dest_h ) / 2;
-	break;
-      }
+    case 'c':
+    default:
+      // center
+      $x0 = (int)( $new_w - $this->_dest_w ) / 2;
+      $y0 = (int)( $new_h - $this->_dest_h ) / 2;
+      break;
+    }
 
     // create destination image at the desired thumb size.
     $_dest = new CGImageBase(array($src['type'],$this->_dest_w,$this->_dest_h));
@@ -218,13 +189,9 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
     imagefill($_dest['rsrc'], 0, 0, $transparent2);
 
     // copy the temp iamge into the dest image.
-    imagealphablending($_dest['rsrc'],TRUE);
-    
+    imagealphablending($_dest['rsrc'],TRUE);  
     $res = imagecopy($_dest['rsrc'],$tmp_rsrc,0,0,$x0,$y0,$new_w,$new_h);
-    if( $res === FALSE )
-      {
-	throw new Exception('Croptofit - stage 2 - failed');
-      }
+    if( $res === FALSE ) throw new Exception('Croptofit - stage 2 - failed');
     imagedestroy($tmp_rsrc);
     return $_dest;
   }
