@@ -127,6 +127,16 @@ class cgsi_utils
     $str = trim($str);
     $res = array(0,0,0);
 
+    if( startswith($str,'#') && strlen($str) == 4 ) {
+      $r = substr($str,1,1); $r = $r.$r;
+      $g = substr($str,2,1); $g = $g.$g;
+      $b = substr($str,3,1); $b = $b.$b;
+      $res[0] = hexdec($r);
+      $res[1] = hexdec($g);
+      $res[2] = hexdec($b);
+      return $res;
+    }
+
     if( startswith($str,'#') && strlen($str) == 7 ) {
       $res[0] = hexdec(substr($str,1,2));
       $res[1] = hexdec(substr($str,3,2));
@@ -205,6 +215,7 @@ class cgsi_utils
     $opp['quality'] = 75;
     $opp['filters'] = array();
     $srcimgsize = ''; // src image size
+    $lastfilter = null;
 
     $tmp = $mod->GetPreference('aliases');
     if( $tmp ) $aliases = unserialize($tmp);
@@ -387,6 +398,12 @@ class cgsi_utils
       }
       else {
 	$srcimgsize = array('width'=>$tmp[0],'height'=>$tmp[1]);
+	$memory_needed = round( $tmp[0] * $tmp[1] * (isset($tmp['bits'])?$tmp['bits']:8) 
+				* (isset($tmp['channels'])?$tmp['channels']/8:3) + 65535 );
+	if( !cge_utils::have_enough_memory($memory_needed) ) {
+	  $outp['error'] = $mod->Lang('error_insufficientmemory');
+	  return $outp;
+	}
       }
     }
 
@@ -420,24 +437,24 @@ class cgsi_utils
 	    break;
 	  case 3:
 	    // rotate 180
-	    $new_filters[] = array('CGImage_Rotate_Filter',array(180,0));
+	    $new_filters[] = array('CGImage_Rotate_Filter',array(180));
 	    break;
 	  case 4:
 	    $new_filters[] = array('CGImage_Flip_Filter',1);
 	    break;
 	  case 5:
 	    $new_filters[] = array('CGImage_Flip_Filter',1);
-	    $new_filters[] = array('CGImage_Rotate_Filter',array(90,0));
+	    $new_filters[] = array('CGImage_Rotate_Filter',array(90));
 	    break;
 	  case 6:
-	    $new_filters[] = array('CGImage_Rotate_Filter',array(90,0));
+	    $new_filters[] = array('CGImage_Rotate_Filter',array(90));
 	    break;
 	  case 7:
 	    $new_filters[] = array('CGImage_Flip_Filter',0);
-	    $new_filters[] = array('CGImage_Rotate_Filter',array(90,0));
+	    $new_filters[] = array('CGImage_Rotate_Filter',array(90));
 	    break;
 	  case 8:
-	    $new_filters[] = array('CGImage_Rotate_Filter',array(-90,0));
+	    $new_filters[] = array('CGImage_Rotate_Filter',array(-90));
 	    break;
 	  }
 
@@ -446,43 +463,6 @@ class cgsi_utils
       }
     }
 
-    // now do some intelligence, and see if the width, and height arguments passed in
-    // match the image size... if not, add a filter.
-    if( !$outp['error'] && $srcfile && ($outp['width'] > 0 || $outp['height'] > 0) && $opp['noautoscale'] == 0 ) {
-      if( $outp['width'] != $srcimgsize['width'] || $outp['height'] != $srcimgsize['height'] ) {
-	// we wanna display the file at a different dimenion.
-	$args = '';
-	$filter = '';
-	if( $outp['width'] && $outp['height'] ) {
-	  // gonna do a crop to fit
-	  $filter = 'CGImage_Croptofit_Filter';
-	  $args = array((int)$outp['width'],(int)$outp['height']);
-	}
-	else if( $outp['width'] ) {
-	  // gonna do a resize
-	  $filter = 'CGImage_Resize_Filter';
-	  $args = array('w',(int)$outp['width']);
-	}
-	else if ( $outp['height'] ) {
-	  // gonna do a resize
-	  $filter = 'CGImage_Resize_Filter';
-	  $args = array('h',(int)$outp['height']);
-	}
-	if( is_array($args) && $filter != '' ) {
-	  $found = 0;
-	  for( $i = 0; $i < count($opp['filters']); $i++ ) {
-	    if( $opp['filters'][$i][0] == 'CGImage_Resize_Filter' ) {
-	      $found = 1;
-	      break;
-	    }
-	  }
-	  if( !$found ) {
-	    $opp['filters'][] = array($filter,$args);
-	  }
-	}
-      }
-    }
-
     // doing responsive images... get device width and height.
     $is_responsive = 0;
     if( !$outp['error'] && $srcfile && $mod->GetPreference('responsive',1) && $opp['noresponsive'] == 0 ) {
@@ -513,7 +493,55 @@ class cgsi_utils
       }
     }
 
-    // if we have max width and/or height... add a filter here at the end
+    // rationalize width/height, max_width, max_height
+    $no_width_height = 0;
+    if( $opp['max_width'] && $outp['width'] ) {
+      $no_width_height = 1;
+      $opp['max_width'] = min($opp['max_width'],$outp['width']);
+    }
+    if( $opp['max_height'] && $outp['height'] ) {
+      $no_width_height = 1;
+      $opp['max_height'] = min($opp['max_height'],$outp['height']);
+    }
+
+    // now do some intelligence, and see if the width, and height arguments passed in
+    // match the image size... if not, and max_width/height aren't already smaller... add a filter.
+    if( !$outp['error'] && $srcfile && $no_width_height == 0 &&
+	($outp['width'] > 0 || $outp['height'] > 0) && $opp['noautoscale'] == 0 ) {
+      if( $outp['width'] != $srcimgsize['width'] || $outp['height'] != $srcimgsize['height'] ) {
+	// we wanna display the file at a different dimenion.
+	$args = '';
+	$filter = '';
+	if( $outp['width'] && $outp['height'] ) {
+	  // gonna do a crop to fit
+	  $filter = 'CGImage_Croptofit_Filter';
+	  $args = array((int)$outp['width'],(int)$outp['height']);
+	}
+	else if( $outp['width'] ) {
+	  // gonna do a resize
+	  $filter = 'CGImage_Resize_Filter';
+	  $args = array('w',(int)$outp['width']);
+	}
+	else if ( $outp['height'] ) {
+	  // gonna do a resize
+	  $filter = 'CGImage_Resize_Filter';
+	  $args = array('h',(int)$outp['height']);
+	}
+	if( is_array($args) && $filter != '' ) {
+	  $found = 0;
+	  for( $i = 0; $i < count($opp['filters']); $i++ ) {
+	    if( $opp['filters'][$i][0] == 'CGImage_Resize_Filter' ) {
+	      $found = 1;
+	      break;
+	    }
+	  }
+	  // add a filter to the end
+	  if( !$found ) $lastfilter = array($filter,$args);
+	}
+      }
+    }
+
+    // if we have max width and/or height... add a filter at the end
     // to make sure that our output never exceeds those max values.
     if( !$outp['error'] && $srcfile &&
 	($opp['max_width'] > 0 || $opp['max_height'] > 0) &&
@@ -565,9 +593,13 @@ class cgsi_utils
 	  $args = array('h',(int)$opp['max_height'],0);
 	}
       }
-      $opp['filters'][] = array($filter,$args);
+      // adjust our lastfilter
+      if( $filter ) $lastfilter = array($filter,$args);
     }
-    
+
+    // if we have a last filter... add it.
+    if( $lastfilter ) $opp['filters'][] = $lastfilter;
+
     //
     // end of smartness stuff... now begin the work
     //
@@ -581,9 +613,10 @@ class cgsi_utils
     if( !$outp['error'] && $srcfile && $want_transform ) {
       // calculate our destination name and url.
       $tmp = basename($srcfile);
+      if( !isset($outp['alt']) ) $outp['alt'] = $tmp;
       $ext = strrchr($tmp,'.');
       $t2 = md5(serialize($opp));
-      $destname = substr($tmp,0,strlen($tmp)-strlen($ext)).'-'.$t2;
+      $destname = 'img-'.$t2;
 
       //$destdir = $config['uploads_path'].'/_'.$mod->GetName();
       $cache_path = $mod->GetPreference('cache_path', cms_join_path('uploads', '_'.$mod->GetName()));
@@ -628,11 +661,19 @@ class cgsi_utils
 	  $i++;
 	}
 
+	// check some stuff
+	if( $opp['noauto'] == 0 &&
+	    (($outp['width'] && $img['width'] < $outp['width']) || 
+	     ($outp['height'] && $img['height'] < $outp['height'])) ) {
+	  // user specified a width, and/or height...but they are smaller than the output of the filtering.
+	  // this will ensure that the tag will match the image.
+	  $outp['width'] = $img['width'];
+	  $outp['height'] = $img['height'];
+	}
+
 	// and write the thing.
 	if( !$outp['error'] && is_object($img) ) {
-	  if( $img['dirty'] ) {
-	    $img->save($dest_fname,$opp['quality']);
-	  }
+	  if( $img['dirty'] ) $img->save($dest_fname,$opp['quality']);
 	}
       }
       catch( Exception $e ) {
@@ -642,14 +683,10 @@ class cgsi_utils
     } // if
 
     // if we have an error, display it... we're done.
-    if( $outp['error'] != '') {
-      return $outp;
-    }
+    if( $outp['error'] != '') return $outp;
 
     // at this point, we're ready to handle building the tag.
-    if( $opp['nobcache'] ) {
-      $dest_url .= '?x='.time();      
-    }
+    if( $opp['nobcache'] ) $dest_url .= '?x='.time();      
 
     if( !isset($outp['alt']) ) {
       if( $dest_fname ) 
@@ -674,9 +711,7 @@ class cgsi_utils
 	$outp['src'] = $dest_url;
       }
 
-      if( !isset($outp['output']) ) {
-	$outp['output'] = $outp['src'];;
-      }
+      if( !isset($outp['output']) ) $outp['output'] = $outp['src'];
     }
     else {
       //
@@ -696,7 +731,7 @@ class cgsi_utils
 	$outp['src'] = $dest_url;
       }
 
-      if( $dest_fname && $srcfile && !$outp['width'] && !$outp['height'] && !$opp['noauto'] ) {
+      if( $dest_fname && $srcfile && !$opp['noauto'] ) {
 	$details = getimagesize($dest_fname);
 	if( is_array($details) ) {
 	  $outp['width']  = (int)$details[0];
